#! /bin/bash

##################################################
# Before running this script, please connect to 
# a Postgres database server first:
#          connect to your database in CDF 
#
# and make sure you have executed the following statement in 
# your shell script to include jdbc in your classpath: 
# export CLASSPATH=/local/packages/jdbc-postgresql/pg74.216.jdbc3.jar:.
# (Note: this is assuming your are using bash shell. To change your 
# current shell environment into bash, type "bash" in your terminal.)
#
# and change the 'database' and 'username' variables below.
#
# you should create the following directory structure, and place the Assignment3.java 
# and Assignment3Cover.txt under the following directory 
# ./A3/yourCDFAccountName/A3
# (Note, "." means the current directory where you put this script, 
# you also put all .dll .sql .java files in this directory)
#
# to run the script: type "markingA3.sh [yourCDFAccountName]" 
# (Note, make sure markingA3.sh is executable. To make it executable, 
# type "chmod +x markingA3.sh" 
##################################################


########Test a single student###########
students=$1   #a single student

a3results=a3.results 
current=`pwd` #current working path

########Change the following database name################
database=csc343h-yourCDFUserName

#######Change the following username####################
username=yourCDFUserName

total=0

##student list in current working path
list=studentList 

rm $list
touch $list

##the directory containing all test results
allresultsPath=a3-allresults

##test the existence of the directory
if [ ! -d $allresultsPath ]
then
    mkdir $allresultsPath
fi

for name in $students
do
	path=$current/A3/$name/A3/
	if [ -d $path ]
	then
		echo "********** OK *************" >> $a3results

	else
		path=$current/A3/$name/A3-late/
	fi
	
	if [ -d $path ] 
	then
		echo "************* DIRECTORY FOUND ***********" >> $a3results
		cd $path
		total=`expr $total + 1`
		results=$name.$a3results
		rm $results
 
		touch $results
		
		delay=0


		echo $name >>$current/$list	

		echo *********Test existence of files********** >> $results
		echo >>$results
		if [ ! -f Assignment3.java ]; then
		    echo "Unable to find Assignment3.java ... " >>$results
		    else
		    echo "Assignment3.java exists.">>$results
		fi

        if [ ! -f Assignment3Cover.txt ]
        then
            echo "Unable to find Assignment3Cover.txt ..." >> $results
            else 
            cat Assignment3Cover.txt >> $results
        fi
	
		echo "********Create all the tables from Assignment3.DDL************" >>$results
		psql -d $database -f $current/Assignment3.ddl
		echo $?
		if [ "$?" != 0 ]
		    then echo ********Failed to create tables from Assignment3.DDL********>>$results 2>&1
		fi
		echo "=============================================">>$results
		echo >>$results

		echo "********Populate the sample instances from A3-data.sql************" >>$results
		psql -d $database -f $current/A3-data.sql
		echo $?
		if [ "$?" != 0 ]
		    then echo ********Failed to populate instances from A3-data.sql********>>$results 2>&1
		fi
		echo "=============================================">>$results
		echo >>$results		
		
		echo ************Testing JDBC part******************>>$results
		echo >>$results

		javac Assignment3.java >>$results 2>&1
		
		cp $current/TestAssignment3ChangePilot.java TestAssignment3ChangePilot.java
		cp $current/TestAssignment3DelayFlights.java TestAssignment3DelayFlights.java
		cp $current/TestAssignment3DeleteFlight.java TestAssignment3DeleteFlight.java
		cp $current/TestAssignment3GetCityCrew.java TestAssignment3GetCityCrew.java
		cp $current/TestAssignment3GetLanguageCount.java TestAssignment3GetLanguageCount.java
		cp $current/TestAssignment3InsertImplment.java TestAssignment3InsertImplment.java
		cp $current/TestAssignment3ScoreKeeper.java TestAssignment3ScoreKeeper.java
		cp $current/TestAssignment3Connections.java TestAssignment3Connections.java

		javac TestAssignment3ChangePilot.java
		javac TestAssignment3DelayFlights.java
		javac TestAssignment3DeleteFlight.java
		javac TestAssignment3GetCityCrew.java
		javac TestAssignment3GetLanguageCount.java
		javac TestAssignment3InsertImplment.java
		javac TestAssignment3ScoreKeeper.java
                javac TestAssignment3Connections.java

		java TestAssignment3Connections $database $username >>$results 2>&1
		java TestAssignment3GetLanguageCount $database $username >>$results 2>&1
		java TestAssignment3GetCityCrew $database $username >>$results 2>&1
		java TestAssignment3DeleteFlight $database $username >>$results 2>&1
		java TestAssignment3DelayFlights $database $username >>$results 2>&1
		java TestAssignment3ChangePilot $database $username >>$results 2>&1
		java TestAssignment3InsertImplment $database $username >>$results 2>&1
                cat tempScore.txt >>$results
		rm -rf tempScore.txt

		rm -rf *.class 

		echo "*********Drop all tables**********"
		psql -d $database -f $current/dropTables
		
		# echo enscript $name\'s resutls into PS file
		# enscript -2r -G -b$name -p$results.ps $results

		echo "*********Copying results to a3-allresults directory*****"
		cp $results $current/$allresultsPath/
		cp $results $current/$allresultsPath/
	else
		echo *************** DIRECTORY CANNOT BE FOUND ************ >> $results
	fi
done
echo $total
